package controllers;

import org.junit.Test;
import org.openqa.selenium.htmlunit.HtmlUnitDriver;
import play.libs.F;
import play.libs.WS;
import play.mvc.Result;
import play.test.TestBrowser;

import static org.fest.assertions.Assertions.assertThat;
import static play.mvc.Http.Status.OK;
import static play.test.Helpers.callAction;
import static play.test.Helpers.charset;
import static play.test.Helpers.contentAsString;
import static play.test.Helpers.contentType;
import static play.test.Helpers.fakeApplication;
import static play.test.Helpers.running;
import static play.test.Helpers.status;
import static play.test.Helpers.testServer;

/**
 * @author shane
 * @since 5/28/12 12:33 PM
 */
public class ApplicationControllerTest {

    @Test
    public void callIndex() {
        Result result = callAction(controllers.routes.ref.Application.index());
        assertThat(status(result)).isEqualTo(OK);
        assertThat(contentType(result)).isEqualTo("text/html");
        assertThat(charset(result)).isEqualTo("utf-8");
        assertThat(contentAsString(result)).contains("hello, world");
    }

    @Test
    public void testIndexWithFakeApp() {
        running(fakeApplication(), new Runnable() {
            @Override
            public void run() {
                // todo test model finder
            }
        });
    }

    @Test
    public void testIndexWithTestServerRunnable() {
        running(testServer(3333), new Runnable() {
            @Override
            public void run() {
                assertThat(
                        WS.url("http://localhost:3333").get().get().getStatus()
                ).isEqualTo(OK);
            }
        });
    }

    @Test
    public void runInBrowser() {
        running(testServer(3333), HtmlUnitDriver.class, new F.Callback<TestBrowser>() {
            public void invoke(TestBrowser browser) {
                browser.goTo("http://localhost:3333");
                assertThat(browser.$("body").getTexts().get(0)).isEqualTo("hello, world");
            }
        });
    }
}
